@@ -1,3 +1,5 @@
+'use strict';
+
 angular.module('docsApp', [
   'ngRoute',
   'ngCookies',
@@ -13,11 +15,9 @@ angular.module('docsApp', [
   'search',
   'tutorials',
   'versions',
-  'bootstrap',
   'ui.bootstrap.dropdown'
 ])
 
-
 .config(['$locationProvider', function($locationProvider) {
   $locationProvider.html5Mode(true).hashPrefix('!');
 }]);
