@@ -1,9 +1,10 @@
-describe("DocsController", function() {
+'use strict';
+
+describe('DocsController', function() {
   var $scope;
 
   angular.module('fake', [])
     .value('$cookies', {})
-    .value('openPlunkr', function() {})
     .value('NG_PAGES', {})
     .value('NG_NAVIGATION', {})
     .value('NG_VERSION', {});
@@ -16,7 +17,7 @@ describe("DocsController", function() {
 
 
   describe('afterPartialLoaded', function() {
-    it("should update the Google Analytics with currentPage path if currentPage exists", inject(function($window) {
+    it('should update the Google Analytics with currentPage path if currentPage exists', inject(function($window) {
       $window._gaq = [];
       $scope.currentPage = { path: 'a/b/c' };
       $scope.$broadcast('$includeContentLoaded');
@@ -24,9 +25,9 @@ describe("DocsController", function() {
     }));
 
 
-    it("should update the Google Analytics with $location.path if currentPage is missing", inject(function($window, $location) {
+    it('should update the Google Analytics with $location.path if currentPage is missing', inject(function($window, $location) {
       $window._gaq = [];
-      spyOn($location, 'path').andReturn('x/y/z');
+      spyOn($location, 'path').and.returnValue('x/y/z');
       $scope.$broadcast('$includeContentLoaded');
       expect($window._gaq.pop()).toEqual(['_trackPageview', 'x/y/z']);
     }));
