@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 
 var _ = require('lodash');
 
@@ -31,4 +31,4 @@ module.exports = function generateVersionDocProcessor(gitData) {
       docs.push(versionDoc);
     }
   };
-};
\ No newline at end of file
+};
