@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 
 module.exports = function jqueryDeployment(getVersion) {
   return {
@@ -39,4 +39,4 @@ module.exports = function jqueryDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
