@@ -1,14 +1,14 @@
-"use strict";
+'use strict';
 
 var versionInfo = require('../../../../lib/versions/version-info');
-var cdnUrl = "//ajax.googleapis.com/ajax/libs/angularjs/" + versionInfo.cdnVersion;
+var cdnUrl = '//ajax.googleapis.com/ajax/libs/angularjs/' + versionInfo.cdnVersion;
 
 module.exports = function productionDeployment(getVersion) {
   return {
     name: 'production',
     examples: {
       commonFiles: {
-        scripts: [ cdnUrl + '/angular.min.js' ]
+        scripts: [cdnUrl + '/angular.min.js']
       },
       dependencyPath: cdnUrl + '/'
     },
@@ -38,4 +38,4 @@ module.exports = function productionDeployment(getVersion) {
       'css/animations.css'
     ]
   };
-};
\ No newline at end of file
+};
