@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 var path = require('canonical-path');
 
 /**
@@ -14,4 +14,4 @@ module.exports = function getVersion(readFilesProcessor) {
     packageFile = packageFile || 'bower.json';
     return require(path.join(sourceFolder,component,packageFile)).version;
   };
-};
\ No newline at end of file
+};
