@@ -1,7 +1,7 @@
 'use strict';
 
 describe('jqLite', function() {
-  var scope, a, b, c;
+  var scope, a, b, c, document;
 
 
   beforeEach(module(provideLog));
@@ -14,22 +14,23 @@ describe('jqLite', function() {
 
 
   beforeEach(inject(function($rootScope) {
+    document = window.document;
     scope = $rootScope;
     jasmine.addMatchers({
       toJqEqual: function() {
         return {
           compare: function(_actual_, expected) {
-            var msg = "Unequal length";
+            var msg = 'Unequal length';
             var message = function() {return msg;};
 
-            var value = _actual_ && expected && _actual_.length == expected.length;
+            var value = _actual_ && expected && _actual_.length === expected.length;
             for (var i = 0; value && i < expected.length; i++) {
               var actual = jqLite(_actual_[i])[0];
               var expect = jqLite(expected[i])[0];
               value = value && equals(expect, actual);
-              msg = "Not equal at index: " + i
-                  + " - Expected: " + expect
-                  + " - Actual: " + actual;
+              msg = 'Not equal at index: ' + i
+                  + ' - Expected: ' + expect
+                  + ' - Actual: ' + actual;
             }
             return { pass: value, message: message };
           }
@@ -229,9 +230,9 @@ describe('jqLite', function() {
           frag = document.createDocumentFragment(),
           $frag = jqLite(frag);
       frag.host = host[0];
-      host.data("foo", 123);
+      host.data('foo', 123);
       host.append($frag);
-      expect($frag.inheritedData("foo")).toBe(123);
+      expect($frag.inheritedData('foo')).toBe(123);
 
       dealoc(host);
       dealoc($frag);
@@ -437,24 +438,24 @@ describe('jqLite', function() {
       var node = document.createElement('div');
 
       expect(jqLite.hasData(node)).toBe(false);
-      expect(jqLite.data(node, "foo")).toBeUndefined();
+      expect(jqLite.data(node, 'foo')).toBeUndefined();
       expect(jqLite.hasData(node)).toBe(false);
 
-      jqLite.data(node, "foo", "bar");
+      jqLite.data(node, 'foo', 'bar');
 
       expect(jqLite.hasData(node)).toBe(true);
-      expect(jqLite.data(node, "foo")).toBe("bar");
-      expect(jqLite(node).data("foo")).toBe("bar");
+      expect(jqLite.data(node, 'foo')).toBe('bar');
+      expect(jqLite(node).data('foo')).toBe('bar');
 
       expect(jqLite.data(node)).toBe(jqLite(node).data());
 
-      jqLite.removeData(node, "foo");
-      expect(jqLite.data(node, "foo")).toBeUndefined();
+      jqLite.removeData(node, 'foo');
+      expect(jqLite.data(node, 'foo')).toBeUndefined();
 
-      jqLite.data(node, "bar", "baz");
+      jqLite.data(node, 'bar', 'baz');
       jqLite.removeData(node);
       jqLite.removeData(node);
-      expect(jqLite.data(node, "bar")).toBeUndefined();
+      expect(jqLite.data(node, 'bar')).toBeUndefined();
 
       jqLite(node).remove();
       expect(jqLite.hasData(node)).toBe(false);
@@ -463,7 +464,7 @@ describe('jqLite', function() {
     it('should emit $destroy event if element removed via remove()', function() {
       var log = '';
       var element = jqLite(a);
-      element.on('$destroy', function() {log+= 'destroy;';});
+      element.on('$destroy', function() {log += 'destroy;';});
       element.remove();
       expect(log).toEqual('destroy;');
     });
@@ -984,7 +985,7 @@ describe('jqLite', function() {
       expect(element[0].innerHTML).toEqual('ab');
       expect(element[1].innerHTML).toEqual('c');
       expect(element.text()).toEqual('abc');
-      expect(element.text('xyz') == element).toBeTruthy();
+      expect(element.text('xyz') === element).toBeTruthy();
       expect(element.text()).toEqual('xyzxyz');
     });
 
@@ -1051,7 +1052,7 @@ describe('jqLite', function() {
       expect(element.length).toEqual(1);
       expect(element[0].innerHTML).toEqual('abc');
       expect(element.html()).toEqual('abc');
-      expect(element.html('xyz') == element).toBeTruthy();
+      expect(element.html('xyz') === element).toBeTruthy();
       expect(element.html()).toEqual('xyz');
     });
   });
@@ -1061,7 +1062,7 @@ describe('jqLite', function() {
     it('should write a value', function() {
       var element = jqLite('<div>abc</div>');
       expect(element.length).toEqual(1);
-      expect(element.empty() == element).toBeTruthy();
+      expect(element.empty() === element).toBeTruthy();
       expect(element.html()).toEqual('');
     });
   });
@@ -1815,7 +1816,7 @@ describe('jqLite', function() {
       iframe_.onload = iframe_.onreadystatechange = function() {
         if (iframe_.contentDocument) test();
       };
-      /* jshint scripturl:true */
+      // eslint-disable-next-line no-script-url
       iframe_.src = 'javascript:false';
       jqLite(document).find('body').append(iframe);
 
@@ -1856,7 +1857,7 @@ describe('jqLite', function() {
     it('should wrap text node', function() {
       var root = jqLite('<div>A&lt;a&gt;B&lt;/a&gt;C</div>');
       var text = root.contents();
-      expect(text.wrap("<span>")[0]).toBe(text[0]);
+      expect(text.wrap('<span>')[0]).toBe(text[0]);
       expect(root.find('span').text()).toEqual('A<a>B</a>C');
     });
     it('should wrap free text node', function() {
@@ -1865,7 +1866,7 @@ describe('jqLite', function() {
       text.remove();
       expect(root.text()).toBe('');
 
-      text.wrap("<span>");
+      text.wrap('<span>');
       expect(text.parent().text()).toEqual('A<a>B</a>C');
     });
     it('should clone elements to be wrapped around target', function() {
@@ -2083,9 +2084,9 @@ describe('jqLite', function() {
 
       element.on('click', pokeSpy);
 
-      element.triggerHandler('click', [{hello: "world"}]);
+      element.triggerHandler('click', [{hello: 'world'}]);
       data = pokeSpy.calls.mostRecent().args[1];
-      expect(data.hello).toBe("world");
+      expect(data.hello).toBe('world');
     });
 
     it('should mark event as prevented if preventDefault is called', function() {
@@ -2121,7 +2122,7 @@ describe('jqLite', function() {
       expect(clickSpy).toHaveBeenCalledTimes(2);
     });
 
-    it("should accept a custom event instead of eventName", function() {
+    it('should accept a custom event instead of eventName', function() {
       var element = jqLite('<a>poke</a>'),
           pokeSpy = jasmine.createSpy('poke'),
           customEvent = {
