@@ -1,37 +1,49 @@
 'use strict';
 
-describe('ngIf', function () {
+describe('ngIf', function() {
   var $scope, $compile, element, $compileProvider;
 
   beforeEach(module(function(_$compileProvider_) {
     $compileProvider = _$compileProvider_;
   }));
-  beforeEach(inject(function ($rootScope, _$compile_) {
+  beforeEach(inject(function($rootScope, _$compile_) {
     $scope = $rootScope.$new();
     $compile = _$compile_;
     element = $compile('<div></div>')($scope);
   }));
 
-  afterEach(function () {
+  afterEach(function() {
     dealoc(element);
   });
 
-  function makeIf(expr) {
-    element.append($compile('<div class="my-class" ng-if="' + expr + '"><div>Hi</div></div>')($scope));
+  function makeIf() {
+    forEach(arguments, function(expr) {
+      element.append($compile('<div class="my-class" ng-if="' + expr + '"><div>Hi</div></div>')($scope));
+    });
     $scope.$apply();
   }
 
-  it('should immediately remove element if condition is false', function () {
-    makeIf('false');
+  it('should immediately remove the element if condition is falsy', function() {
+    makeIf('false', 'undefined', 'null', 'NaN', '\'\'', '0');
     expect(element.children().length).toBe(0);
   });
 
-  it('should leave the element if condition is true', function () {
+  it('should leave the element if condition is true', function() {
     makeIf('true');
     expect(element.children().length).toBe(1);
   });
 
-  it('should not add the element twice if the condition goes from true to true', function () {
+  it('should leave the element if the condition is a non-empty string', function() {
+    makeIf('\'f\'', '\'0\'', '\'false\'', '\'no\'', '\'n\'', '\'[]\'');
+    expect(element.children().length).toBe(6);
+  });
+
+  it('should leave the element if the condition is an object', function() {
+    makeIf('[]', '{}');
+    expect(element.children().length).toBe(2);
+  });
+
+  it('should not add the element twice if the condition goes from true to true', function() {
     $scope.hello = 'true1';
     makeIf('hello');
     expect(element.children().length).toBe(1);
@@ -39,7 +51,7 @@ describe('ngIf', function () {
     expect(element.children().length).toBe(1);
   });
 
-  it('should not recreate the element if the condition goes from true to true', function () {
+  it('should not recreate the element if the condition goes from true to true', function() {
     $scope.hello = 'true1';
     makeIf('hello');
     element.children().data('flag', true);
@@ -47,7 +59,7 @@ describe('ngIf', function () {
     expect(element.children().data('flag')).toBe(true);
   });
 
-  it('should create then remove the element if condition changes', function () {
+  it('should create then remove the element if condition changes', function() {
     $scope.hello = true;
     makeIf('hello');
     expect(element.children().length).toBe(1);
@@ -55,7 +67,7 @@ describe('ngIf', function () {
     expect(element.children().length).toBe(0);
   });
 
-  it('should create a new scope every time the expression evaluates to true', function () {
+  it('should create a new scope every time the expression evaluates to true', function() {
     $scope.$apply('value = true');
     element.append($compile(
       '<div ng-if="value"><span ng-init="value=false"></span></div>'
@@ -84,7 +96,7 @@ describe('ngIf', function () {
     expect(destroyed).toBe(true);
   });
 
-  it('should play nice with other elements beside it', function () {
+  it('should play nice with other elements beside it', function() {
     $scope.values = [1, 2, 3, 4];
     element.append($compile(
       '<div ng-repeat="i in values"></div>' +
@@ -207,7 +219,7 @@ describe('ngIf and transcludes', function() {
         link: function(scope) {
           scope.val = 'value in iso scope';
         },
-        restrict: 'A',
+        restrict: 'E',
         transclude: true,
         template: '<div ng-if="true">val={{val}}-<div ng-transclude></div></div>',
         scope: {}
@@ -215,7 +227,7 @@ describe('ngIf and transcludes', function() {
     });
     inject(function($compile, $rootScope) {
       $rootScope.val = 'transcluded content';
-      var element = $compile('<div iso><span ng-bind="val"></span></div>')($rootScope);
+      var element = $compile('<iso><span ng-bind="val"></span></iso>')($rootScope);
       $rootScope.$digest();
       expect(trim(element.text())).toEqual('val=value in iso scope-transcluded content');
       dealoc(element);
@@ -223,7 +235,7 @@ describe('ngIf and transcludes', function() {
   });
 });
 
-describe('ngIf animations', function () {
+describe('ngIf animations', function() {
   var body, element, $rootElement;
 
   function html(content) {
@@ -238,12 +250,12 @@ describe('ngIf animations', function () {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = jqLite(document.body);
+      body = jqLite(window.document.body);
       body.append($rootElement);
     };
   }));
 
-  afterEach(function(){
+  afterEach(function() {
     dealoc(body);
     dealoc(element);
   });
@@ -276,7 +288,7 @@ describe('ngIf animations', function () {
   );
 
   it('should fire off the leave animation',
-    inject(function ($compile, $rootScope, $animate) {
+    inject(function($compile, $rootScope, $animate) {
       var item;
       var $scope = $rootScope.$new();
       element = $compile(html(
@@ -303,17 +315,15 @@ describe('ngIf animations', function () {
 
   it('should destroy the previous leave animation if a new one takes place', function() {
     module(function($provide) {
-      $provide.value('$animate', {
-        enabled : function() { return true; },
-        leave : function() {
-          //DOM operation left blank
-        },
-        enter : function(element, parent) {
-          parent.append(element);
-        }
+      $provide.decorator('$animate', function($delegate, $$q) {
+        var emptyPromise = $$q.defer().promise;
+        $delegate.leave = function() {
+          return emptyPromise;
+        };
+        return $delegate;
       });
     });
-    inject(function ($compile, $rootScope, $animate) {
+    inject(function($compile, $rootScope, $animate) {
       var item;
       var $scope = $rootScope.$new();
       element = $compile(html(
@@ -339,4 +349,23 @@ describe('ngIf animations', function () {
     });
   });
 
+  it('should work with svg elements when the svg container is transcluded', function() {
+    module(function($compileProvider) {
+      $compileProvider.directive('svgContainer', function() {
+        return {
+          template: '<svg ng-transclude></svg>',
+          replace: true,
+          transclude: true
+        };
+      });
+    });
+    inject(function($compile, $rootScope) {
+      element = $compile('<svg-container><circle ng-if="flag"></circle></svg-container>')($rootScope);
+      $rootScope.flag = true;
+      $rootScope.$apply();
+
+      var circle = element.find('circle');
+      expect(circle[0].toString()).toMatch(/SVG/);
+    });
+  });
 });
