@@ -135,7 +135,7 @@ describe('validators', function() {
     it('should not throw an error when scope pattern can\'t be found', function() {
       expect(function() {
         var inputElm = helper.compileInput('<input type="text" ng-model="foo" ng-pattern="fooRegexp" />');
-        $rootScope.$apply("foo = 'bar'");
+        $rootScope.$apply('foo = \'bar\'');
       }).not.toThrowError(/^\[ngPattern:noregexp\] Expected fooRegexp to be a RegExp but was/);
     });
 
@@ -508,22 +508,22 @@ describe('validators', function() {
     it('should allow bindings via ngRequired', function() {
       var inputElm = helper.compileInput('<input type="text" ng-model="value" ng-required="required" />');
 
-      $rootScope.$apply("required = false");
+      $rootScope.$apply('required = false');
 
       helper.changeInputValueTo('');
       expect(inputElm).toBeValid();
 
 
-      $rootScope.$apply("required = true");
+      $rootScope.$apply('required = true');
       expect(inputElm).toBeInvalid();
 
-      $rootScope.$apply("value = 'some'");
+      $rootScope.$apply('value = \'some\'');
       expect(inputElm).toBeValid();
 
       helper.changeInputValueTo('');
       expect(inputElm).toBeInvalid();
 
-      $rootScope.$apply("required = false");
+      $rootScope.$apply('required = false');
       expect(inputElm).toBeValid();
     });
 
@@ -540,7 +540,7 @@ describe('validators', function() {
     it('should be $invalid but $pristine if not touched', function() {
       var inputElm = helper.compileInput('<input type="text" ng-model="name" name="alias" required />');
 
-      $rootScope.$apply("name = null");
+      $rootScope.$apply('name = null');
 
       expect(inputElm).toBeInvalid();
       expect(inputElm).toBePristine();
@@ -587,10 +587,10 @@ describe('validators', function() {
       $rootScope.$apply();
       expect(inputElm).toBeInvalid();
 
-      $rootScope.$apply("answer = true");
+      $rootScope.$apply('answer = true');
       expect(inputElm).toBeValid();
 
-      $rootScope.$apply("answer = false");
+      $rootScope.$apply('answer = false');
       expect(inputElm).toBeValid();
     });
 
