@@ -3,18 +3,18 @@
 
 describe('$httpBackend', function() {
 
-  var $backend, $browser, callbacks,
+  var $backend, $browser, $jsonpCallbacks,
       xhr, fakeDocument, callback;
 
-
   beforeEach(inject(function($injector) {
-    callbacks = {counter: 0};
+
     $browser = $injector.get('$browser');
+
     fakeDocument = {
       $$scripts: [],
       createElement: jasmine.createSpy('createElement').and.callFake(function() {
         // Return a proper script element...
-        return document.createElement(arguments[0]);
+        return window.document.createElement(arguments[0]);
       }),
       body: {
         appendChild: jasmine.createSpy('body.appendChild').and.callFake(function(script) {
@@ -22,13 +22,33 @@ describe('$httpBackend', function() {
         }),
         removeChild: jasmine.createSpy('body.removeChild').and.callFake(function(script) {
           var index = fakeDocument.$$scripts.indexOf(script);
-          if (index != -1) {
+          if (index !== -1) {
             fakeDocument.$$scripts.splice(index, 1);
           }
         })
       }
     };
-    $backend = createHttpBackend($browser, createMockXhr, $browser.defer, callbacks, fakeDocument);
+
+    $jsonpCallbacks = {
+      createCallback: function(url) {
+        $jsonpCallbacks[url] = function(data) {
+          $jsonpCallbacks[url].called = true;
+          $jsonpCallbacks[url].data = data;
+        };
+        return url;
+      },
+      wasCalled: function(callbackPath) {
+        return $jsonpCallbacks[callbackPath].called;
+      },
+      getResponse: function(callbackPath) {
+        return $jsonpCallbacks[callbackPath].data;
+      },
+      removeCallback: function(callbackPath) {
+        delete $jsonpCallbacks[callbackPath];
+      }
+    };
+
+    $backend = createHttpBackend($browser, createMockXhr, $browser.defer, $jsonpCallbacks, fakeDocument);
     callback = jasmine.createSpy('done');
   }));
 
@@ -52,7 +72,7 @@ describe('$httpBackend', function() {
 
   it('should pass the correct falsy value to send if falsy body is set (excluding undefined, NaN)',
     function() {
-      var values = [false, 0, "", null];
+      var values = [false, 0, '', null];
       angular.forEach(values, function(value) {
         $backend('GET', '/some-url', value, noop);
         xhr = MockXhr.$$lastInstance;
@@ -135,10 +155,11 @@ describe('$httpBackend', function() {
   });
 
   it('should not try to read response data when request is aborted', function() {
-    callback.and.callFake(function(status, response, headers) {
+    callback.and.callFake(function(status, response, headers, statusText) {
       expect(status).toBe(-1);
       expect(response).toBe(null);
       expect(headers).toBe(null);
+      expect(statusText).toBe('');
     });
     $backend('GET', '/url', null, callback, {}, 2000);
     xhr = MockXhr.$$lastInstance;
@@ -152,6 +173,22 @@ describe('$httpBackend', function() {
     expect(callback).toHaveBeenCalledOnce();
   });
 
+  it('should complete the request on timeout', function() {
+    callback.and.callFake(function(status, response, headers, statusText) {
+      expect(status).toBe(-1);
+      expect(response).toBe(null);
+      expect(headers).toBe(null);
+      expect(statusText).toBe('');
+    });
+    $backend('GET', '/url', null, callback, {});
+    xhr = MockXhr.$$lastInstance;
+
+    expect(callback).not.toHaveBeenCalled();
+
+    xhr.ontimeout();
+    expect(callback).toHaveBeenCalledOnce();
+  });
+
   it('should abort request on timeout', function() {
     callback.and.callFake(function(status, response) {
       expect(status).toBe(-1);
@@ -233,9 +270,10 @@ describe('$httpBackend', function() {
     expect(MockXhr.$$lastInstance.withCredentials).toBe(true);
   });
 
+
   it('should call $xhrFactory with method and url', function() {
     var mockXhrFactory = jasmine.createSpy('mockXhrFactory').and.callFake(createMockXhr);
-    $backend = createHttpBackend($browser, mockXhrFactory, $browser.defer, callbacks, fakeDocument);
+    $backend = createHttpBackend($browser, mockXhrFactory, $browser.defer, $jsonpCallbacks, fakeDocument);
     $backend('GET', '/some-url', 'some-data', noop);
     expect(mockXhrFactory).toHaveBeenCalledWith('GET', '/some-url');
   });
@@ -294,7 +332,7 @@ describe('$httpBackend', function() {
 
   describe('JSONP', function() {
 
-    var SCRIPT_URL = /([^\?]*)\?cb=angular\.callbacks\.(.*)/;
+    var SCRIPT_URL = /([^\?]*)\?cb=(.*)/;
 
 
     it('should add script tag for JSONP request', function() {
@@ -310,14 +348,16 @@ describe('$httpBackend', function() {
           url = script.src.match(SCRIPT_URL);
 
       expect(url[1]).toBe('http://example.org/path');
-      callbacks[url[2]]('some-data');
-      browserTrigger(script, "load");
+      $jsonpCallbacks[url[2]]('some-data');
+      browserTrigger(script, 'load');
 
       expect(callback).toHaveBeenCalledOnce();
     });
 
 
     it('should clean up the callback and remove the script', function() {
+      spyOn($jsonpCallbacks, 'removeCallback').and.callThrough();
+
       $backend('JSONP', 'http://example.org/path?cb=JSON_CALLBACK', null, callback);
       expect(fakeDocument.$$scripts.length).toBe(1);
 
@@ -325,10 +365,10 @@ describe('$httpBackend', function() {
       var script = fakeDocument.$$scripts.shift(),
           callbackId = script.src.match(SCRIPT_URL)[2];
 
-      callbacks[callbackId]('some-data');
-      browserTrigger(script, "load");
+      $jsonpCallbacks[callbackId]('some-data');
+      browserTrigger(script, 'load');
 
-      expect(callbacks[callbackId]).toBe(angular.noop);
+      expect($jsonpCallbacks.removeCallback).toHaveBeenCalledOnceWith(callbackId);
       expect(fakeDocument.body.removeChild).toHaveBeenCalledOnceWith(script);
     });
 
@@ -343,7 +383,9 @@ describe('$httpBackend', function() {
     });
 
 
-    it('should abort request on timeout and replace callback with noop', function() {
+    it('should abort request on timeout and remove JSONP callback', function() {
+      spyOn($jsonpCallbacks, 'removeCallback').and.callThrough();
+
       callback.and.callFake(function(status, response) {
         expect(status).toBe(-1);
       });
@@ -359,7 +401,7 @@ describe('$httpBackend', function() {
       expect(fakeDocument.$$scripts.length).toBe(0);
       expect(callback).toHaveBeenCalledOnce();
 
-      expect(callbacks[callbackId]).toBe(angular.noop);
+      expect($jsonpCallbacks.removeCallback).toHaveBeenCalledOnceWith(callbackId);
     });
 
 
@@ -367,6 +409,7 @@ describe('$httpBackend', function() {
     // TODO(vojta): test whether it fires "async-end" on both success and error
   });
 
+
   describe('protocols that return 0 status code', function() {
 
     function respond(status, content) {
@@ -376,10 +419,12 @@ describe('$httpBackend', function() {
       xhr.onload();
     }
 
+    beforeEach(function() {
+      $backend = createHttpBackend($browser, createMockXhr);
+    });
+
 
     it('should convert 0 to 200 if content and file protocol', function() {
-      $backend = createHttpBackend($browser, createMockXhr);
-
       $backend('GET', 'file:///whatever/index.html', null, callback);
       respond(0, 'SOME CONTENT');
 
@@ -388,8 +433,6 @@ describe('$httpBackend', function() {
     });
 
     it('should convert 0 to 200 if content for protocols other than file', function() {
-      $backend = createHttpBackend($browser, createMockXhr);
-
       $backend('GET', 'someProtocol:///whatever/index.html', null, callback);
       respond(0, 'SOME CONTENT');
 
@@ -398,8 +441,6 @@ describe('$httpBackend', function() {
     });
 
     it('should convert 0 to 404 if no content and file protocol', function() {
-      $backend = createHttpBackend($browser, createMockXhr);
-
       $backend('GET', 'file:///whatever/index.html', null, callback);
       respond(0, '');
 
@@ -408,8 +449,6 @@ describe('$httpBackend', function() {
     });
 
     it('should not convert 0 to 404 if no content for protocols other than file', function() {
-      $backend = createHttpBackend($browser, createMockXhr);
-
       $backend('GET', 'someProtocol:///whatever/index.html', null, callback);
       respond(0, '');
 
@@ -423,21 +462,19 @@ describe('$httpBackend', function() {
 
       //temporarily overriding the DOM element to pretend that the test runs origin with file:// protocol
       urlParsingNode = {
-        hash: "#/C:/",
-        host: "",
-        hostname: "",
-        href: "file:///C:/base#!/C:/foo",
-        pathname: "/C:/foo",
-        port: "",
-        protocol: "file:",
-        search: "",
+        hash: '#/C:/',
+        host: '',
+        hostname: '',
+        href: 'file:///C:/base#!/C:/foo',
+        pathname: '/C:/foo',
+        port: '',
+        protocol: 'file:',
+        search: '',
         setAttribute: angular.noop
       };
 
       try {
 
-        $backend = createHttpBackend($browser, createMockXhr);
-
         $backend('GET', '/whatever/index.html', null, callback);
         respond(0, '');
 
@@ -449,10 +486,7 @@ describe('$httpBackend', function() {
       }
     });
 
-
     it('should return original backend status code if different from 0', function() {
-      $backend = createHttpBackend($browser, createMockXhr);
-
       // request to http://
       $backend('POST', 'http://rest_api/create_whatever', null, callback);
       respond(201, '');
