@@ -80,12 +80,13 @@ describe('ngView', function() {
   });
 
 
-  it('should instantiate controller with an alias', function() {
-    var log = [], controllerScope,
-        Ctrl = function($scope) {
-          this.name = 'alias';
-          controllerScope = $scope;
-        };
+    it('should instantiate controller with an alias', function() {
+      var log = [], controllerScope;
+
+      function Ctrl($scope) {
+        this.name = 'alias';
+        controllerScope = $scope;
+      }
 
     module(function($compileProvider, $routeProvider) {
       $routeProvider.when('/some', {templateUrl: '/tpl.html', controller: Ctrl, controllerAs: 'ctrl'});
@@ -568,10 +569,10 @@ describe('ngView', function() {
       $rootScope.$digest();
 
       angular.forEach(element.contents(), function(node) {
-        if (node.nodeType == 3 /* text node */) {
+        if (node.nodeType === 3 /* text node */) {
           expect(angular.element(node).scope()).not.toBe($route.current.scope);
           expect(angular.element(node).controller()).not.toBeDefined();
-        } else if (node.nodeType == 8 /* comment node */) {
+        } else if (node.nodeType === 8 /* comment node */) {
           expect(angular.element(node).scope()).toBe(element.scope());
           expect(angular.element(node).controller()).toBe(element.controller());
         } else {
@@ -630,7 +631,7 @@ describe('ngView and transcludes', function() {
     });
   });
 
-  it("should compile its content correctly (although we remove it later)", function() {
+  it('should compile its content correctly (although we remove it later)', function() {
     var testElement;
     module(function($compileProvider, $routeProvider) {
       $routeProvider.when('/view', {template: ' '});
@@ -709,7 +710,7 @@ describe('ngView animations', function() {
     // we need to run animation on attached elements;
     return function(_$rootElement_) {
       $rootElement = _$rootElement_;
-      body = angular.element(document.body);
+      body = angular.element(window.document.body);
     };
   }));
 
